@@ -29,7 +29,6 @@
 
 #include "oxygenmenubarstatedata.h"
 #include "../oxygengtkutils.h"
-#include "../config.h"
 
 #include <gtk/gtk.h>
 
@@ -40,13 +39,6 @@ namespace Oxygen
     void MenuBarStateData::connect( GtkWidget* widget )
     {
 
-        #if OXYGEN_DEBUG
-        std::cerr
-            << "Oxygen::MenuBarStateData::connect - "
-            << " " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")"
-            << std::endl;
-        #endif
-
         _target = widget;
         _motionId.connect( G_OBJECT(widget), "motion-notify-event", G_CALLBACK( motionNotifyEvent ), this );
         _leaveId.connect( G_OBJECT(widget), "leave-notify-event", G_CALLBACK( leaveNotifyEvent ), this );
@@ -68,13 +60,6 @@ namespace Oxygen
     void MenuBarStateData::disconnect( GtkWidget* )
     {
 
-        #if OXYGEN_DEBUG
-        std::cerr
-            << "Oxygen::MenuBarStateData::disconnect - "
-            << " " << _target << " (" << (_target ? G_OBJECT_TYPE_NAME( _target ) : "0x0") << ")"
-            << std::endl;
-        #endif
-
         _target = 0L;
 
         // disconnect signal
@@ -85,72 +70,10 @@ namespace Oxygen
         _current._timeLine.disconnect();
         _previous._timeLine.disconnect();
 
-        // disconnect all children
-        for( ChildrenMap::iterator iter = _children.begin(); iter != _children.end(); ++iter )
-        { iter->second.disconnect(); }
-
-        _children.clear();
-
         FollowMouseData::disconnect();
 
     }
 
-
-    //________________________________________________________________________________
-    void MenuBarStateData::registerChild( GtkWidget* widget )
-    {
-        if( widget && _children.find( widget ) == _children.end() )
-        {
-
-            #if OXYGEN_DEBUG
-            std::cerr
-                << "Oxygen::MenuBarStateData::registerChild -"
-                << " " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")"
-                << std::endl;
-            #endif
-
-            Signal destroyId;
-            destroyId.connect( G_OBJECT( widget ), "destroy", G_CALLBACK( childDestroyNotifyEvent ), this );
-            _children.insert( std::make_pair( widget, destroyId ) );
-        }
-
-    }
-
-    //________________________________________________________________________________
-    void MenuBarStateData::unregisterChild( GtkWidget* widget )
-    {
-
-        #if OXYGEN_DEBUG
-        std::cerr
-            << "Oxygen::MenuBarStateData::unregisterChild -"
-            << " " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")"
-            << std::endl;
-        #endif
-
-        ChildrenMap::iterator iter( _children.find( widget ) );
-
-        // erase from children map
-        if( iter != _children.end() )
-        {
-            iter->second.disconnect();
-            _children.erase( iter );
-        }
-
-        // reset corresponding data, if matches
-        if( widget == _previous._widget )
-        {
-            _previous._widget = 0L;
-            _previous._timeLine.disconnect();
-        }
-
-        if( widget == _current._widget )
-        {
-            _current._widget = 0L;
-            _current._timeLine.disconnect();
-        }
-
-    }
-
     //________________________________________________________________________________
     void MenuBarStateData::updateItems( GdkEventType type )
     {
@@ -174,24 +97,23 @@ namespace Oxygen
             if( !( child->data && GTK_IS_MENU_ITEM( child->data ) ) ) continue;
 
             GtkWidget* childWidget( GTK_WIDGET( child->data ) );
-            registerChild( childWidget );
-            const GtkStateType state( gtk_widget_get_state( childWidget ) );
+            const GtkStateFlags state( gtk_widget_get_state_flags( childWidget ) );
 
             // do nothing for disabled child
-            if( state == GTK_STATE_INSENSITIVE ) continue;
+            if( state&GTK_STATE_FLAG_INSENSITIVE ) continue;
 
             const GtkAllocation allocation( Gtk::gtk_widget_get_allocation( childWidget ) );
             if( Gtk::gdk_rectangle_contains( &allocation, xPointer, yPointer ) )
             {
 
                 activeFound = true;
-                if( state != GTK_STATE_PRELIGHT )
+                if( !(state&GTK_STATE_FLAG_PRELIGHT) )
                 {
                     updateState( childWidget, allocation, true );
-                    if( !isLeaveEvent ) gtk_widget_set_state( childWidget, GTK_STATE_PRELIGHT );
+                    if( !isLeaveEvent ) gtk_widget_set_state_flags( childWidget, GTK_STATE_FLAG_PRELIGHT, true );
                 }
 
-            } else if( state != GTK_STATE_NORMAL ) {
+            } else if( state&GTK_STATE_FLAG_PRELIGHT ) {
 
                 activeWidget = childWidget;
 
@@ -206,7 +128,7 @@ namespace Oxygen
 
         // disable previous active widget, if either another active widget was found, or this one is not active
         if( activeWidget && (activeFound || !menuItemIsActive( activeWidget ) ) )
-        { gtk_widget_set_state( activeWidget, GTK_STATE_NORMAL ); }
+        { gtk_widget_set_state_flags( activeWidget, GTK_STATE_FLAG_NORMAL, true ); }
 
         return;
 
@@ -284,7 +206,7 @@ namespace Oxygen
             // move current to previous; clear current, and animate
             _previous.copy( _current );
             _current.clear();
-            if( _previous.isValid() && gtk_widget_get_state( _previous._widget ) == GTK_STATE_PRELIGHT ) _previous._timeLine.start();
+            if( _previous.isValid() && gtk_widget_get_state_flags( _previous._widget )&GTK_STATE_FLAG_PRELIGHT ) _previous._timeLine.start();
 
             return true;
 
@@ -317,19 +239,6 @@ namespace Oxygen
 
     }
 
-    //____________________________________________________________________________________________
-    gboolean MenuBarStateData::childDestroyNotifyEvent( GtkWidget* widget, gpointer data )
-    {
-        #if OXYGEN_DEBUG
-        std::cerr
-            << "Oxygen::MenuBarStateData::childDestroyNotifyEvent -"
-            << " " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")"
-            << std::endl;
-        #endif
-        static_cast<MenuBarStateData*>(data)->unregisterChild( widget );
-        return FALSE;
-    }
-
     //________________________________________________________________________________
     gboolean MenuBarStateData::motionNotifyEvent(GtkWidget*, GdkEventMotion*, gpointer pointer )
     {
