@@ -72,7 +72,6 @@ namespace Oxygen
             static const char* widgetTypes[] = {
                 "ExoIconView",
                 "FMIconContainer",
-                "MessageList",
                 "EMailDisplay",
                 0L };
             for( unsigned int i = 0; widgetTypes[i]; i++ )
@@ -158,7 +157,7 @@ namespace Oxygen
             setFocused( widget, gtk_widget_has_focus( widget ) );
 
             // set initial hover
-            const bool enabled( gtk_widget_get_state( widget ) != GTK_STATE_INSENSITIVE );
+            const bool enabled( !(gtk_widget_get_state_flags( widget )&GTK_STATE_FLAG_INSENSITIVE) );
 
             // on connection, needs to check whether mouse pointer is in widget or not
             // to have the proper initial value of the hover flag
