@@ -48,13 +48,13 @@ namespace Oxygen
             gtk_tree_view_set_rules_hint( treeView, true );
 
             GtkWidget* parent( gtk_widget_get_parent( widget ) );
-            GtkScrolledWindow* scrolledWindow(0);
-            if(
-                GTK_IS_SCROLLED_WINDOW( parent ) &&
-                gtk_scrolled_window_get_shadow_type( (scrolledWindow = GTK_SCROLLED_WINDOW( parent ) ) ) != GTK_SHADOW_IN &&
-                !Gtk::gtk_parent_is_shadow_in( parent ) )
-            { gtk_scrolled_window_set_shadow_type( scrolledWindow, GTK_SHADOW_IN ); }
+            if( GTK_IS_SCROLLED_WINDOW( parent ) )
+            {
+                GtkScrolledWindow* scrolledWindow( GTK_SCROLLED_WINDOW( parent ) );
+                if( gtk_scrolled_window_get_shadow_type( scrolledWindow ) != GTK_SHADOW_IN && !Gtk::gtk_parent_is_shadow_in( parent ) )
+                { gtk_scrolled_window_set_shadow_type( scrolledWindow, GTK_SHADOW_IN ); }
 
+            }
 
         }
 
