@@ -2,7 +2,7 @@
 #define oxygentreeviewengine_h
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
 * Copyright (c) 2010 Ruslan Kabatsayev <b7.10110111@gmail.com>
 *
 * This  library is free  software; you can  redistribute it and/or
@@ -55,26 +55,14 @@ namespace Oxygen
         bool hovered( GtkWidget* widget )
         { return data().value( widget ).hovered(); }
 
-        //! true if treeview data is dirty
-        bool isDirty( GtkWidget* widget )
-        { return data().value( widget ).isDirty(); }
-
-        //! update hovered cell for given widget
-        void updateHoveredCell( GtkWidget* widget )
-        { return data().value( widget ).updateHoveredCell(); }
-
         //! true if given cell is hovered
         bool isCellHovered( GtkWidget* widget, const Gtk::CellInfo& info )
         { return data().value( widget ).isCellHovered( info ); }
 
+        //! true if given cell is hovered
         bool isCellHovered( GtkWidget* widget, const Gtk::CellInfo& info, bool fullWidth )
         { return data().value( widget ).isCellHovered( info, fullWidth ); }
 
-        private:
-
-        //! cursor
-        bool _cursorLoaded;
-        GdkCursor* _cursor;
     };
 
 }
