@@ -2,7 +2,7 @@
 #define oxygengtkicons_h
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
 *
 * inspired notably from kdelibs/kdeui/color/kcolorutils.h
 * Copyright (C) 2007 Matthew Woehlke <mw_triad@users.sourceforge.net>
@@ -25,7 +25,6 @@
 * MA 02110-1301, USA.
 */
 
-#include "oxygengtkrc.h"
 #include "oxygenpathlist.h"
 
 #include <string>
@@ -51,8 +50,8 @@ namespace Oxygen
         //! load translations
         void loadTranslations( const std::string& filename );
 
-        //! generate rc file
-        Gtk::RC generate( const PathList& );
+        //! generate icons
+        void generate( const PathList& );
 
         //! set icon size
         void setIconSize( const std::string&, unsigned int value );
@@ -66,9 +65,6 @@ namespace Oxygen
         //! generate iconSet for given option
         GtkIconSet* generate( const std::string& gtkIconName, const std::string& kdeIconName, const PathList& pathList ) const;
 
-        //! generate rc code for given option
-        std::string generateString( const std::string& gtkIconName, const std::string& kdeIconName, const PathList& pathList ) const;
-
         private:
 
         //!@name icon map
@@ -119,9 +115,6 @@ namespace Oxygen
         //! icon factory
         GtkIconFactory* _factory;
 
-        //! local GtkRC
-        Gtk::RC _rc;
-
         //! dirty flag. Set to true when options needs update
         bool _dirty;
 
