@@ -91,6 +91,7 @@ namespace Oxygen
         _activeShadowConfiguration( Palette::Active ),
         _inactiveShadowConfiguration( Palette::Inactive ),
         _argbEnabled( true ),
+        _widgetExplorerEnabled( true ),
         _initialized( false ),
         _kdeColorsInitialized( false ),
         _gtkColorsInitialized( false ),
@@ -146,6 +147,7 @@ namespace Oxygen
         /* TODO: in principle this should be needed only once */
         GtkSettings* settings( gtk_settings_get_default() );
         gtk_settings_set_long_property( settings, "gtk-alternative-button-order", 1, "oxygen-gtk" );
+        gtk_settings_set_long_property( settings, "gtk-primary-button-warps-slider", 0, "oxygen-gtk" );
 
         // clear gtkrc
         _css.clear();
@@ -665,53 +667,73 @@ namespace Oxygen
         // customize gtk palette
         _palette.setGroup( Palette::Active );
 
-        // color definitions
-        _css.addColorDefinition( "theme_base_color", _palette.color( Palette::Base ) );
-        _css.addColorDefinition( "theme_bg_color", _palette.color( Palette::Window ) );
-        _css.addColorDefinition( "theme_selected_bg_color", _palette.color( Palette::Selected ) );
-
-        _css.addColorDefinition( "theme_text_color", _palette.color( Palette::Text ) );
-        _css.addColorDefinition( "theme_fg_color", _palette.color( Palette::WindowText ) );
-        _css.addColorDefinition( "theme_selected_fg_color", _palette.color( Palette::SelectedText ) );
-
-        _css.addColorDefinition( "theme_unfocused_base_color", _palette.color( Palette::Inactive, Palette::Base ) );
-        _css.addColorDefinition( "theme_unfocused_text_color", _palette.color( Palette::Inactive, Palette::Text ) );
-        _css.addColorDefinition( "theme_unfocused_fg_color", _palette.color( Palette::Inactive, Palette::WindowText ) );
-        _css.addColorDefinition( "theme_unfocused_bg_color", _palette.color( Palette::Inactive, Palette::Window ) );
-        _css.addColorDefinition( "theme_unfocused_selected_bg_color", _palette.color( Palette::Inactive, Palette::Selected ) );
-        _css.addColorDefinition( "theme_unfocused_selected_fg_color", _palette.color( Palette::Active, Palette::Text ) );
-
         // default text color
         _css.setCurrentSection( Gtk::CSS::defaultSection() );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Window ) ) );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::WindowText ) ) );
         addLinkColors( "[Colors:Window]" );
 
+        // default insensitive text color
+        _css.addSection( "*:insensitive" );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::Disabled, Palette::WindowText ) ) );
+
+        // default background color
+        _css.addSection(
+            ".background, "
+            ".floating-bar" );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Window ) ) );
+
+        // default insensitive background color
+        _css.addSection( ".background:insensitive" );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Disabled, Palette::Window ) ) );
+
+        // transparent widgets
+        _css.addSection(
+            ".check, "
+            ".frame, "
+            ".info, "
+            ".scale, "
+            ".through, "
+            "GtkExpander, "
+            "GtkHandleBox, "
+            "GtkImage, "
+            "GtkInfoBar, "
+            "GtkLabel, "
+            "GtkMenuItem, "
+            "GtkOverlay, "
+            "GtkRevealer, "
+            "GtkScrolledWindow, "
+            "GtkSwitch, "
+            "GtkViewport" );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, "transparent" ) );
+
+
+        // hover and focus color
+        /*
+        border color is used in order not to interfere with widgets that have custom background set.
+        Also, even if the css is actually not used, it is needed to set different colors (either foreground, background or text) if one wants to have the
+        proper style rendering method called, on, e.g. hover
+        */
         _css.addSection( "*:selected" );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Selected ) ) );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::WindowText ) ) );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BORDER_COLOR, _palette.color( Palette::Selected ) ) );
 
         _css.addSection( "*:hover" );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Hover ) ) );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::WindowText ) ) );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BORDER_COLOR, _palette.color( Palette::Hover ) ) );
 
         _css.addSection( ".highlight" );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Focus ) ) );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::WindowText ) ) );
-
-        _css.addSection( "*:insensitive" );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Disabled, Palette::Window ) ) );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::Disabled, Palette::WindowText ) ) );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BORDER_COLOR, _palette.color( Palette::Focus ) ) );
 
         // entries
         _css.addSection(
             ".view, "
             ".entry, "
+            ".list, "
             "GtkEntry" );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Base ) ) );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::Text ) ) );
         addLinkColors( "[Colors:View]" );
 
+        // text selection
         _css.addSection(
             ".view:insensitive, "
             ".entry:insensitive, "
@@ -722,20 +744,23 @@ namespace Oxygen
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Disabled, Palette::Base ) ) );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::Disabled, Palette::Text ) ) );
 
+        _css.addSection(
+            ".view:selected:focus, "
+            ".entry:selected:focus, "
+            "GtkEntry:selected:focus, "
+            "GtkTreeView:selected:focus, "
+            "GtkTextView:selected:focus" );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Active, Palette::Selected ) ) );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::Active, Palette::SelectedText ) ) );
+
         _css.addSection(
             ".view:selected, "
             ".entry:selected, "
             "GtkEntry:selected, "
             "GtkTreeView:selected, "
             "GtkTextView:selected" );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Selected ) ) );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::SelectedText ) ) );
-
-        // FIXME: this is an evince bug: for content-view.view, selected is used for selected+focus.
-        // We need to adjust the colors accordingly.
-        _css.addSection( ".content-view.view:selected" );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Selected ) ) );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::Active, Palette::SelectedText ) ) );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Inactive, Palette::Selected ) ) );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::Active, Palette::Text ) ) );
 
         // sidebars
         _css.addSection( "GtkAssistant .sidebar" );
@@ -772,7 +797,6 @@ namespace Oxygen
         // tooltips
         _css.addSection( "GtkWindow#gtk-tooltip" );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Tooltip ) ) );
-        _css.addToCurrentSection( "  padding: 3px;" );
 
         _css.addSection( "GtkWindow#gtk-tooltip GtkLabel" );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::TooltipText ) ) );
@@ -780,7 +804,7 @@ namespace Oxygen
 
         // rubber band selection (at least for nautilus)
         // FIXME: is Palette::Selected the proper color? Is 0.35 the proper alpha?
-        _css.addSection( ".view.rubberband,.rubberband" );
+        _css.addSection( ".view.rubberband, .rubberband" );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BORDER_COLOR, _palette.color( Palette::Selected ) ) );
         {
             std::ostringstream color;
@@ -1033,6 +1057,11 @@ namespace Oxygen
         // animation steps
         TimeLine::setSteps( _oxygen.getOption( "[Style]", "AnimationSteps" ).toVariant<int>( 10 ) );
 
+        // widget explorer
+        _widgetExplorerEnabled =
+            _oxygen.getOption( "[Style]", "WidgetExplorerEnabled" ).toVariant<std::string>("false") == "true" ||
+            _oxygen.getOption( "[Style]", "WidgetExplorerGtkEnabled" ).toVariant<std::string>("false") == "true";
+
         // window decoration button size
         std::string buttonSize( _oxygen.getValue( "[Windeco]", "ButtonSize", "Normal") );
         if( buttonSize == "Small" ) _buttonSize = ButtonSmall;
@@ -1060,7 +1089,7 @@ namespace Oxygen
         else if( titleAlign == "Right" ) _titleAlignment = PANGO_ALIGN_RIGHT;
         else _titleAlignment = PANGO_ALIGN_CENTER;
 
-        // Windeco radial gradient enable option
+        // window decoration radial gradient enable option
         std::string wdBlendType( _oxygen.getValue( "[Windeco]", "BlendColor", "Follow Style Hint" ) );
         if( wdBlendType == "Follow Style Hint" ) _windecoBlendType=FollowStyleHint;
         else if( wdBlendType == "Radial Gradient" ) _windecoBlendType=RadialGradient;
