@@ -323,7 +323,6 @@ namespace Oxygen
         // cast data to window manager
         WindowManager &manager( *static_cast<WindowManager*>(data ) );
 
-
         bool registered( false );
         if( GTK_IS_WINDOW( widget ) ||
             GTK_IS_VIEWPORT( widget ) ||
@@ -373,7 +372,7 @@ namespace Oxygen
         if( !GTK_IS_WIDGET( widget ) ) return FALSE;
 
         // cast data to window manager
-        WindowManager &manager( *static_cast<WindowManager*>(data ) );
+        WindowManager &manager( *static_cast<WindowManager*>(data) );
 
         // check mode
         if( manager._dragMode == Disabled ) return TRUE;
@@ -513,7 +512,7 @@ namespace Oxygen
     {
 
         if( _dragMode == Disabled ) return false;
-        else if( !_dragAboutToStart && checkCursor( event->window ) && withinWidget(widget, event ) && useEvent( widget, event ) )
+        else if( !_dragAboutToStart && withinWidget(widget, event ) && useEvent( widget, event ) )
         {
 
             // store widget and event position
@@ -541,18 +540,6 @@ namespace Oxygen
 
     }
 
-    //_________________________________________________
-    bool WindowManager::checkCursor( GdkWindow* window ) const
-    {
-        if( !window ) return true;
-        GdkCursor* cursor = gdk_window_get_cursor( window );
-
-        // do not propagate if widget's cursor is currently modified,
-        // since it is usually indicative of mouse action
-        return !cursor || gdk_cursor_get_cursor_type( cursor ) == GDK_ARROW;
-
-    }
-
     //_________________________________________________
     bool WindowManager::withinWidget( GtkWidget* widget, GdkEventButton* event ) const
     {
@@ -675,7 +662,7 @@ namespace Oxygen
             GtkWidget* childWidget( GTK_WIDGET( child->data ) );
 
             // check widget state and type
-            if( gtk_widget_get_state( childWidget ) == GTK_STATE_PRELIGHT )
+            if( gtk_widget_get_state_flags( childWidget )&GTK_STATE_FLAG_PRELIGHT )
             {
 
                 // if widget is prelight, we don't need to check where event happen,
@@ -694,11 +681,17 @@ namespace Oxygen
             if( !( event && withinWidget( childWidget, event ) ) )
             { continue; }
 
+            // do not propagate if widget's cursor is currently modified,
+            // since it is usually indicative of mouse action
+            GdkCursor* cursor = gdk_window_get_cursor( window );
+            if( cursor && gdk_cursor_get_cursor_type( cursor ) != GDK_ARROW )
+            { usable = false; }
+
             // check special cases for which grab should not be enabled
             if( usable && (
                 widgetIsBlackListed( childWidget ) ||
                 ( GTK_IS_NOTEBOOK( widget ) && Gtk::gtk_notebook_is_tab_label( GTK_NOTEBOOK( widget ), childWidget ) ) ||
-                ( GTK_IS_BUTTON( childWidget ) && gtk_widget_get_state( childWidget ) != GTK_STATE_INSENSITIVE ) ||
+                ( GTK_IS_BUTTON( childWidget ) && !(gtk_widget_get_state_flags( childWidget )&GTK_STATE_FLAG_INSENSITIVE) ) ||
                 ( gtk_widget_get_events ( childWidget ) & (GDK_BUTTON_PRESS_MASK|GDK_BUTTON_RELEASE_MASK) ) ||
                 ( GTK_IS_MENU_ITEM( childWidget ) ) ||
                 ( GTK_IS_SCROLLED_WINDOW( childWidget ) && ( !inNoteBook || gtk_widget_is_focus( childWidget ) ) ) ) )
